@@ -1,4 +1,4 @@
-use poem::{handler, route, RouteMethod, Server};
+use poem::{handler, route, route::get, Server};
 
 const CERT: &str = r#"
 -----BEGIN CERTIFICATE-----
@@ -64,7 +64,7 @@ fn index() -> &'static str {
 
 #[tokio::main]
 async fn main() {
-    let app = route().at("/", RouteMethod::new().get(index));
+    let app = route().at("/", get(index));
 
     Server::bind("127.0.0.1:3000")
         .await
